

def milliseconds_allowed_strings():
    return ['ms', 'milliseconds', 'm']


def seconds_allowed_strings():
    return ['s', 'seconds', 'sec']


def hours_allowed_strings():
    return ['h', 'hours', 'hrs', 'hour']


def days_allowed_strings():
    return ['d', 'days', 'day']


def years_allowed_strings():
    return ['y', 'years', 'yrs', 'year']


def minutes_allowed_strings():
    return ['min', 'minute', 'minutes']



from pytime_converter.helper import recognized_unit_measure as rum
from pytime_converter.helper.input_regex_parser import parse_input


class ConvertUnitNotRecognizedException(Exception):
    pass


class InputNotInValidFormatException(Exception):
    pass


def get_milliseconds_value_for_input(input_string: str) -> float:

    matches = parse_input(input=input_string)

    if len(matches) == 0:
        raise InputNotInValidFormatException('the input is not recognized')

    number_value = convert_string_to_float(input=matches[0])

    convert_value = 1

    if len(matches) > 1 and matches[1] != '':
        if matches[1] in rum.milliseconds_allowed_strings():
            convert_value = 1
        elif matches[1] in rum.seconds_allowed_strings():
            convert_value = 1000
        elif matches[1] in rum.minutes_allowed_strings():
            convert_value = 1000 * 60
        elif matches[1] in rum.hours_allowed_strings():
            convert_value = 1000 * 60 * 60
        elif matches[1] in rum.days_allowed_strings():
            convert_value = 1000 * 60 * 60 * 24
        elif matches[1] in rum.years_allowed_strings():
            convert_value = 1000 * 60 * 60 * 24 * 365
        else:
            raise ConvertUnitNotRecognizedException(
                f'no unit conversion value found for unit {matches[1]}'
            )

    return int(number_value * convert_value)


def convert_string_to_float(input: str) -> float:
    try:
        return float(input)
    except ValueError:
        raise InputNotInValidFormatException('the value is not a valid float')



# -*- coding: utf-8 -*-
from distutils.core import setup

package_dir = \
{'': 'src'}

packages = \
['pytime_converter', 'pytime_converter.helper']

package_data = \
{'': ['*'], 'pytime_converter': ['service/*']}

setup_kwargs = {
    'name': 'pytime-converter',
    'version': '0.1.8',
    'description': 'Easily convert differt time-range format to standard ones',
    'long_description': "# PyTime Converter\n\n[![codecov](https://codecov.io/gh/massicer/PyTime-Converter/branch/master/graph/badge.svg)](https://codecov.io/gh/massicer/PyTime-Converter)\n[![Build Status](https://travis-ci.org/massicer/PyTime-Converter.svg?branch=master)](https://travis-ci.org/massicer/PyTime-Converter)\n\n\nEasily manage different `time interval values` and convert them to `milliseconds`.\n\n## How To use\n\n### Available time formats\n| Unit Measure       | Allowed Sigles | default |\n| ------------- |:-----:| :-----:|\n| `milliseconds`  | `ms` , `milliseconds`, `sec`| `X`\n| `seconds`  | `seconds` , `s`, `sec`|\n| `minutes`  | `min` , `minute`, `minutes`|\n| `hours`  | `h` , `hours`, `hrs`, `hour`|\n| `days`  | `d` , `days`, `day`|\n| `years`  | `y` , `years`, `yrs`, `year`|\n\n\n\n- Simply using the `get_milliseconds_value_for_input` with the string value to convert. The below example use the number value `90` and the sigle `s`. \n\n```python\nfrom pytime_converter.service.convert_service import get_milliseconds_value_for_input\n\njob_time =  '90 seconds' \n\nassert 90000 == get_milliseconds_value_for_input(job_time)\n```\n\n- When the time measure unit is missing the default value is `milliseconds`\n\n```python\nfrom pytime_converter.service.convert_service import get_milliseconds_value_for_input\n\nassert 90 == get_milliseconds_value_for_input('90')\n\n# Using seconds\nassert 9000 == get_milliseconds_value_for_input('9 seconds')\nassert 9000 == get_milliseconds_value_for_input('9 s')\nassert 9000 == get_milliseconds_value_for_input('9 sec')\n```\n\n## Getting Started\n\nThese instructions will get you a copy of the project up and running on your local machine for development and testing purposes. See deployment for notes on how to deploy the project on a live system.\n\n### Prerequisites\n\n- [Poetry >=0.12](https://python-poetry.org)\n- Python ^3.5\n- Virtualenvwrapper or other virtualenv environment\n- make utility\n\n\n### Installing\n\n- Install it with pypi\n    ```\n    pip install pytime-converter\n    ```\n\n- Or Clone/download the repository\n\n    ```\n    git clone https://github.com/massicer/Env-Time-Converter.git\n    ```\n\n    Install project package\n    ```\n    make install\n    ```\n\n    or without the make utility\n    ```\n    poetry install\n    ```\n## Running the tests\n\nClone the rempo and simply type \n```\nmake test\n```\n\n\n## Authors\n\n* **[Massimiliano Ceriani](massimilianoceriani08@gmail.com)** - *Initial work* - [PYTime Converter](https://github.com/massicer/PyTime-Converter)\n\n## License\n\nThis project is licensed under the MIT License - see the [LICENSE.md](LICENSE.md) file for details\n\n",
    'author': 'Massimiliano Ceriani',
    'author_email': 'massimiliano.ceriani08@gmail.com',
    'url': 'https://github.com/massicer/PyTime-Converter',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
